@@ -23,6 +23,12 @@
 #define HAVE_PERMSTRING 1
 #define HAVE_STRING 1
 
+/* Define if <new> exists and works. */
+#undef HAVE_NEW_HDR
+
+/* Define if you have u_intXX_t types but not uintXX_t types. */
+#undef HAVE_U_INT_TYPES
+
 @TOP@
 @BOTTOM@
 
@@ -43,6 +49,6 @@ double good_strtod(const char *nptr, char **endptr);
 #ifdef __cplusplus
 }
 /* Get rid of a possible inline macro under C++. */
-# undef inline
+# define inline inline
 #endif
 #endif
